
# This file was automatically generated by Dist::Zilla::Plugin::ModuleBuild v5.020.
use strict;
use warnings;

use Module::Build 0.28;


my %module_build_args = (
  "build_requires" => {
    "Module::Build" => "0.28"
  },
  "configure_requires" => {
    "ExtUtils::MakeMaker" => 0,
    "Module::Build" => "0.28"
  },
  "dist_abstract" => "Create graphical web counters",
  "dist_author" => [
    "Olaf Alders <olaf\@wundercounter.com>"
  ],
  "dist_name" => "Acme-Odometer",
  "dist_version" => "0.0.4",
  "license" => "perl",
  "module_name" => "Acme::Odometer",
  "recommends" => {},
  "recursive_test_files" => 1,
  "requires" => {
    "GD" => 0,
    "Memoize" => 0,
    "Moo" => "1.001",
    "MooX::Types::MooseLike::Numeric" => 0,
    "Path::Class" => 0,
    "namespace::clean" => 0,
    "perl" => "5.006",
    "strict" => 0,
    "warnings" => 0
  },
  "script_files" => [],
  "test_requires" => {
    "Test::Most" => 0
  }
);


my %fallback_build_requires = (
  "Module::Build" => "0.28",
  "Test::Most" => 0
);


unless ( eval { Module::Build->VERSION(0.4004) } ) {
  delete $module_build_args{test_requires};
  $module_build_args{build_requires} = \%fallback_build_requires;
}

my $build = Module::Build->new(%module_build_args);

$build->create_build_script;
